@@ -1,7 +1,16 @@
+from logging.handlers import RotatingFileHandler
+import logging
+from configuration.LoggingConstants import LoggingConstants
+import sys
+from CreateLoggerController import CreateLoggerController
+logger = CreateLoggerController("SendDataController").getLogger()
+loggingConstants = LoggingConstants()
+
 class SendDataController:
 
     def __init__(self):
         pass
+
     def sendDataInQueue(self, sender, processedCoT, clientInformationQueue):
         try:
             try:
@@ -16,7 +25,7 @@ class SendDataController:
                         else:
                             break
             except:
-                print('no marti')
+                pass
             
             if sender == processedCoT:
                 for client in clientInformationQueue:
@@ -40,5 +49,4 @@ class SendDataController:
                     else:
                         break
         except Exception as e:
-            print('data reception error')
-            print(e)
\ No newline at end of file
+            logger.error(loggingConstants.SENDDATACONTROLLERSENDDATAINQUEUEERROR+str(e))
\ No newline at end of file
