@@ -1,26 +1,13 @@
-import os
-from pathlib import PurePath
 class LoggingConstants:
     def __init__(self):
         #main logging config
-        # if on a unix type system with /var/log put the logs there
-        if os.path.isdir('/var/log'):
-            self.PARENTPATH = '/var'
-            self.LOGDIRECTORY = 'log'
-        else:
-            # determine the log path the old way under the execution path
-            self.CURRENTPATH = os.path.dirname(os.path.realpath(__file__))
-            self.CURRENTPATH = PurePath(self.CURRENTPATH)
-            self.PARENTPATH = str(self.CURRENTPATH.parents[0])
-            self.LOGDIRECTORY = 'logs'
-
         self.LOGFORMAT = '%(levelname)s : %(asctime)s : %(filename)s:%(lineno)d : %(message)s'
         self.LOGNAME = 'FTS'
-
-        self.ERRORLOG = str(PurePath(self.PARENTPATH, f"{self.LOGDIRECTORY}/{self.LOGNAME}_error.log"))
-        self.DEBUGLOG = str(PurePath(self.PARENTPATH, f"{self.LOGDIRECTORY}/{self.LOGNAME}_debug.log"))
-        self.INFOLOG = str(PurePath(self.PARENTPATH, f"{self.LOGDIRECTORY}/{self.LOGNAME}_info.log"))
-        self.HTTPLOG = str(PurePath(self.PARENTPATH, f"{self.LOGDIRECTORY}/{self.LOGNAME}_http.log"))
+        self.LOGDIRECTORY = 'logs'
+        self.WARNINGLOG = f"{self.LOGDIRECTORY}/{self.LOGNAME}_warning.log"
+        self.DEBUGLOG = f"{self.LOGDIRECTORY}/{self.LOGNAME}_debug.log"
+        self.INFOLOG = f"{self.LOGDIRECTORY}/{self.LOGNAME}_info.log"
+        self.HTTPLOG = f"{self.LOGDIRECTORY}/{self.LOGNAME}_http.log"
         self.DELIMITER = ' ? '
         self.MAXFILESIZE = 100000
         self.BACKUPCOUNT = 5
@@ -48,7 +35,7 @@ class LoggingConstants:
         self.CLIENTDISCONNECTSTART = 'initiating client disconnection'
         self.REMOVE = "remove"
         self.DESTROY = 'destroy'
-        self.CLIENTDISCONNECTEND = 'client disconnection has concluded '
+        self.CLIENTDISCONNECTEND = 'there has been an error in the reception of generic data'
         self.CLIENTDISCONNECTERROR = 'there has been an error in the reception of generic data'
 
         #monitorRawCoT
@@ -131,4 +118,4 @@ class LoggingConstants:
         #XMLCoTController
         #determine CoT general
         self.XMLCOTCONTROLLERDETERMINECOTGENERALERRORA = "exception XMLCoTController in determining general CoT type A "
-        self.XMLCOTCONTROLLERDETERMINECOTGENERALERRORB = "exception XMLCoTController in determining general CoT type B "
+        self.XMLCOTCONTROLLERDETERMINECOTGENERALERRORB = "exception XMLCoTController in determining general CoT type B "
\ No newline at end of file
